@@ -1,3 +1,3 @@
 from . import video, user, dynamic, bangumi, live, article, exceptions, tools, audio, channel, utils
 from .utils import aid2bvid, bvid2aid, upload_image, Verify, Danmaku, Color, request_settings
-from .common import get_vote_info
+from .common import get_vote_info, web_search, web_search_by_type
