@@ -411,4 +411,29 @@ def dynamic_share(type_: str, rid: int, content: str,
                 "sketch[target_url]": target_url
             })
     resp = utils.post(url=api["url"], cookies=verify.get_cookies(), data=data)
-    return resp
\ No newline at end of file
+    return resp
+
+
+def web_search(keyword: str):
+    """
+    只指定关键字在web进行搜索，返回未经处理的字典
+    """
+    api = API["common"]["search"]["web_search"]
+    params = {
+        "keyword": keyword
+    }
+    resp = utils.get(url=api["url"], params=params)
+    return resp
+
+def web_search_by_type(keyword: str, search_type: str):
+    """
+    指定关键字和类型在web进行搜索，返回未经处理的字典
+    类型：视频(video)、番剧(media_bangumi)、影视(media_ft)、直播(live)、专栏(article)、话题(topic)、用户(bili_user)
+    """
+    api = API["common"]["search"]["web_search_by_type"]
+    params = {
+        "keyword": keyword,
+        "search_type": search_type
+    }
+    resp = utils.get(url=api["url"], params=params)
+    return resp
